@@ -1,3 +1,5 @@
+import json, django
+from future.builtins import str, int
 from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.db import transaction
@@ -6,7 +8,6 @@ from django.utils.translation import ugettext_lazy as _
 from polymorphic.admin import PolymorphicParentModelAdmin, PolymorphicModelChoiceForm
 from polymorphic_tree.models import PolymorphicMPTTModel
 from mptt.admin import MPTTModelAdmin
-import json
 
 try:
     # Django 1.6 requires this
@@ -31,14 +32,17 @@ try:
 except ImportError:
     extra_list_filters = ()
 else:
-    # Django 1.4:
+    # Django 1.4+:
     class NodeTypeListFilter(SimpleListFilter):
         parameter_name = 'ct_id'
         title = _('node type')
 
         def lookups(self, request, model_admin):
+            if django.VERSION >= (1, 6):
+                return model_admin.get_child_type_choices(request, 'change')
             return model_admin.get_child_type_choices()
 
+        # Whoops: Django 1.6 didn't rename this one!
         def queryset(self, request, queryset):
             if self.value():
                 queryset = queryset.filter(polymorphic_ctype_id=self.value())
@@ -146,7 +150,10 @@ class PolymorphicMPTTParentModelAdmin(PolymorphicParentModelAdmin, MPTTModelAdmi
         Add custom URLs for moving nodes.
         """
         base_urls = super(PolymorphicMPTTParentModelAdmin, self).get_urls()
-        info = self.model._meta.app_label, self.model._meta.module_name
+        try:
+            info = self.model._meta.app_label, self.model._meta.model_name
+        except:
+            info = self.model._meta.app_label, self.model._meta.module_name
         extra_urls = [
             url(r'^api/node-moved/$', self.admin_site.admin_view(self.api_node_moved_view), name='{0}_{1}_moved'.format(*info)),
             url(r'^(\d+)/move_up/$', self.admin_site.admin_view(self.move_up_view)),
@@ -168,10 +175,10 @@ class PolymorphicMPTTParentModelAdmin(PolymorphicParentModelAdmin, MPTTModelAdmi
         Update the position of a node, from a API request.
         """
         try:
-            moved_id = long(request.POST['moved_id'])
-            target_id = long(request.POST['target_id'])
+            moved_id = int(request.POST['moved_id'])
+            target_id = int(request.POST['target_id'])
             position = request.POST['position']
-            previous_parent_id = long(request.POST['previous_parent_id']) or None
+            previous_parent_id = int(request.POST['previous_parent_id']) or None
 
             # Not using .non_polymorphic() so all models are downcasted to the derived model.
             # This causes the signal below to be emitted from the proper class as well.
